==> gnupoc-package-1.08.tar.gz: gnupoc-package-1.08/tools/makesis-4/src/signutils.h <==
/*
    Makesis 4
    Copyright 2007 Martin Storsj

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU Lesser General Public License as
    published by the Free Software Foundation; either version 2.1 of the
    License, or (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA

    In addition, as a special exception, the copyright holder of this
    program gives permission to link the code of its release of Makesis 4
    with the OpenSSL project's "OpenSSL" library (or with modified
    versions of it that use the same license as the "OpenSSL" library) and
    with modified Symbian code under the Symbian Example Source license;
    and distribute the linked executables. You must obey the GNU Lesser
    General Public License in all respects for all of the code used other
    than "OpenSSL" and the Symbian copyrighted code. If you modify this
    file, you may extend this exception to your version of the file, but
    you are not obliged to do so. If you do not wish to do so, delete this
    exception statement from your version.

    Martin Storsj
    martin@martin.st
*/

#ifndef __SIGNUTILS_H
#define __SIGNUTILS_H

#include "sisfield.h"

enum SigType {
	SigAuto,
	SigDsa,
	SigRsa
};

enum SignUtilError {
	SignFileNotFound,
	SignBadKey,
	SignBadCert,
	SignOpenSSLErr
};

char* loadTextFile(const char* name);

void initSigning();
SISSignatureCertificateChain* makeChain(SISField* controller, const char* certData, const char* keyData, const char* passphrase, SigType type = SigAuto);
void cleanupSigning();

#endif

==> gnupoc-package-1.22.tar.gz: gnupoc-package-1.22/tools/makesis-4/src/signutils.h <==
/*
    Makesis 4
    Copyright 2007 Martin Storsjo

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU Lesser General Public License as
    published by the Free Software Foundation; either version 2.1 of the
    License, or (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA

    In addition, as a special exception, the copyright holder of this
    program gives permission to link the code of its release of Makesis 4
    with the OpenSSL project's "OpenSSL" library (or with modified
    versions of it that use the same license as the "OpenSSL" library) and
    with modified Symbian code under the Symbian Example Source license;
    and distribute the linked executables. You must obey the GNU Lesser
    General Public License in all respects for all of the code used other
    than "OpenSSL" and the Symbian copyrighted code. If you modify this
    file, you may extend this exception to your version of the file, but
    you are not obliged to do so. If you do not wish to do so, delete this
    exception statement from your version.

    Martin Storsjo
    martin@martin.st
*/

#ifndef __SIGNUTILS_H
#define __SIGNUTILS_H

#include "sisfield.h"

enum SigType {
	SigAuto,
	SigDsa,
	SigRsa
};

enum SignUtilError {
	SignFileNotFound,
	SignBadKey,
	SignBadCert,
	SignOpenSSLErr
};

char* loadTextFile(const char* name, int* length = NULL);

void initSigning();
SISSignatureCertificateChain* makeChain(SISField* controller, const char* certData, int certLen, const char* keyData, int keyLen, const char* passphrase, SigType type = SigAuto);
void cleanupSigning();

#endif
